@@ -4,6 +4,7 @@ import os.path as osp
 import torch
 import numpy as np
 
+from gorilla.config import derive_logger
 from gorilla.evaluation import DatasetEvaluator
 from .metric import (accuracy, accuracy_for_each_class)
 
@@ -14,16 +15,14 @@ class ClsEvaluator(DatasetEvaluator):
     """
 
     def __init__(self,
-                 logger=None,
                  class_wise=False,
                  num_classes=None):
         r"""
         Args:
             dataset_root (str): Root directory of dataset
-            logger ()
             class_wise (bool): If True, return class-wise accuracy additionally
         """
-        self.logger = logger
+        self.logger = derive_logger(__name__)
         if class_wise:
             assert num_classes is not None, "num_classes should be given if class_wise=True"
         self.class_wise = class_wise
